@@ -15,7 +15,7 @@ use Types::Standard qw( ArrayRef Bool );
 
 use Moo::Role;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 my @options = ( 'help', 'man' );
 do {
@@ -96,30 +96,31 @@ MooX::Role::CliOptions - Wrapper to simplify using Moo with Getopt::Long
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =head1 SYNOPSIS
 
 This is a minimal script that composes C<MooX::Role::CliOptions>.
   
-    #!perl!
-    package My::CliOptions;
+    #!/usr/bin/perl
+    package My::Moodulino;
   
     use Moo;
     with 'MooX::Role::CliOptions';
   
     # initialize script attributes/variables
     has option1 => (
-        is => 'ro',
-        isa => sub {
+        is      => 'ro',
+        isa     => sub {
             die 'Illegal value for option1'
               unless $_[0] =~ /^foo|bar$/;
         },
+        default => '',
     );
   
     ...
   
-    # this is what makes the script a modulino
+    # this makes the script a modulino
     do {
         my $app = __PACKAGE__->init(
             argv     => \@ARGV,
@@ -141,26 +142,42 @@ This is a minimal script that composes C<MooX::Role::CliOptions>.
   
 =head1 DESCRIPTION
 
-This role was written to help standardize command line script behavior and
-greatly improve their testability.
+This role was written to help standardize command line script behavior and,
+if written as a modulino, greatly improve testability. It should be noted
+that all example code snippets below are based on the modulino style but
+the normal, non-modulino style is also supported. See the example and test
+scripts in the distribution for further info if needed.
 
+The default object created when composing this Role has the following
+structure (assuming a package name of C<My::Moodulino> as above and no
+additional attributes are defined in the composing class.)
+  
+ $VAR1 = bless( {
+  'debug' => 1,
+  'verbose' => 1,
+  'argv' => []
+ }, 'My::Moodulino' );
+  
 =head1 EXPORTS
 
-None.
+None. (Not applicable in a Role.)
 
 =head1 ATTRIBUTES
 
-Three attributes are provided for the composing package, two of which are
-accepted as command line arguments and the third being created from the final
-C<@ARGV> values after processing by C<Getopt::Long>.
+Three read-only attributes are provided for the composing package, two of
+which are exposed as command line arguments and the third being created from
+the final C<@ARGV> values after processing by C<Getopt::Long>.
 
-NOTE: Both C<--debug> and C<--verbose> can be disabled by setting the
-environment variable C<MRC_NO_STDOPTS> to a "true" value B<before> composing
-C<MooX::Role::CliOptions> into you script. This allows you to completely remove
-them or redefine them to suit your needs if so desired. I.e. you might want
-C<--debug> to be "off" by default. If you decide to redefine them you must
-supply a suitable attribute in your script. This does NOT affect C<--help>
-or C<--man>.
+NOTE: Both C<debug> and C<verbose> can be eliminated from the Role by setting
+the environment variable C<MRC_NO_STDOPTS> to a "true" value B<before>
+composing C<MooX::Role::CliOptions> into your script. This allows you to
+completely remove them or redefine them to suit your needs as desired. For
+example, you might want C<--debug> to be "off" by default. If you decide to
+redefine them you must supply a suitable attribute in your script. This does
+NOT affect the C<--help> or C<--man> command line options or the C<argv>
+attribute.
+  
+The following example demonstrates this:
   
  #!perl!
   
@@ -170,6 +187,12 @@ or C<--man>.
     $ENV{MRC_NO_STDOPTS} = 1;
  }
   
+ use Moo;
+ with 'MooX::Role::CliOptions';
+  
+ # not required but strongly recommended by ths author
+ use MooX::StrictConstructor;
+
  has debug => (
     is => 'ro',
     default => 0,
@@ -184,9 +207,6 @@ or C<--man>.
     default => 0,
  );
   
- use Moo;
- with 'MooX::Role::CliOptions';
-  
  do {
     my $app = __PACKAGE__->init(
         argv => \@ARGV,
@@ -203,37 +223,51 @@ or C<--man>.
   
 =head2 debug (Boolean read-only)
 
-Commonly used to either enable extra reports and/or disable potentially
-dangerous operations such as database modifications.
+Exposed as the negatable C<--debug> command line option.
 
-Default: ON. Is turned off with C<--nodebug> on the command line.
+Default: Boolean TRUE (1). Is turned off with C<--nodebug> on the command
+line. (Paranoia is your friend.)
+
+Commonly used to enable diagnostic reports and/or disable potentially
+dangerous operations such as database modifications.
 
 Note: Implies the setting for C<verbose> if C<--verbose> or C<--noverbose> is
 not explicitly set on the command line.
 
 =head2 verbose (Boolean read-only)
 
-Tyically used to add extra information to the output. Often used in
-conjunction with CL--debug>.
+Exposed as the negatable C<--verbose> command line option.
+
+Typically used to add extra information to the output. Often used in
+conjunction with C<--debug>.
 
 Default: Will be the same as C<debug> if not explicitly set with either
-C<--verbose> or C<--noverbose>. This behaviour was chosen since that is
-the most common usage in the author's experience.
+C<--verbose> or C<--noverbose>. This behavior was chosen since that is
+the most common usage pattern in the author's experience.
 
-The most likely patter would be
+The most likely usage patterns would be
   
- # in a crontab where no visible output would be desired
+ # in a crontab where no verbose output would be desired (verbose will
+ # default to OFF.)
  /my_script --nodebug
   
- # manually run from the cli if screen output is desired
+ # manually run from the cli where normal operation is needed and verbose
+ # output is desired
  /my_script --nodebug --verbose
 
 =head2 argv (read-only)
 
 Returns an arrayref to the contents of C<@ARGV> after processing by
-C<Getopt::Long>.
+C<Getopt::Long>. This is syntactic sugar for using C<@ARGV> directly.
 
-=head1 OTHER COMMAND LINE ARGUMENTS
+Default: An empty arrayref if no command line arguments other than options
+recognized by C<Getopt::Long> are supplied.
+
+=head1 OTHER COMMAND LINE OPTIONS
+
+The following command line options are also accepted, but are not
+associated with an attribute since both will cause an immediate exit via
+C<Pod::Usage> after displaying the appropriate message.
 
 =head2 --help
 
@@ -248,9 +282,9 @@ Will use C<pod2usage> to display the full POD if available.
 
 =head2 init
 
-This is the workhorse that performs necessary actions and makes the actual
-call to the composing package's C<new> constructor. Its return value is
-the resulting object of the composing package type.
+This is the workhorse that integrates C<Getopt::Long> with the call to the
+composing package's C<new> constructor. Its return value is the resulting
+object of the composing package type.
 
 =head3 Parameters
 
@@ -268,9 +302,10 @@ will be left in C<@ARGV>. They can also be accessed via C<$app-E<gt>argv>.
 =item add_opts (optional)
 
 You can add your own command line options by using this. Simply place the
-specifications for any additional options that you want in an array ref as
-shown below and be sure to declare an attribute to hold the option data
-as processed by C<Getopt::Long>. (See the example script to make things clear.)
+C<Getopt::Long> specification for any additional options that you want in an
+array ref as shown below and be sure to declare an attribute to hold the
+option data as processed by C<Getopt::Long>. (See the example scripts to make
+things clear.)
   
  # in your script
  has custom1 => (
@@ -297,7 +332,13 @@ test that you deem are needed as well as a default.
 
 =head1 SEE ALSO
 
-C<examples/moodulino.pl> for a fully functional script,
+=over 4
+
+=item C<examples/moodulino.pl> for a functional modulino script.
+
+=item C<examples/myscript.pl> for a functional non-modulino script.
+
+=back
 
 =head1 AUTHOR
 
